Guard

Struct Guard 

pub struct Guard<'lock, T> { /* private fields */ }
The lock guard for Local.

Because this lock type only supports exclusive locking, the same guard type is used for both exclusive and shared guards.