pub trait Lifetime<'this, ImplicitBounds: Sealed = Bounds<&'this Self>> {
type ExclusiveGuard;
type SharedGuard;
}Expand description
Associated types of a Lock with a specific lifetime applied.
Required Associated Types
Sourcetype ExclusiveGuard
type ExclusiveGuard
A RAII exclusive guard on the lock; when this type is dropped, the lock must unlock.
A RAII shared guard on the lock; when this type is dropped, the lock must unlock.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".